@@ -3,43 +3,7 @@
 /**
  * the navigation frame - displays server, db and table selection tree
  *
- * @version $Id: navigation.php 11043 2008-01-05 15:12:30Z lem9 $
- * @uses $GLOBALS['PMA_List_Database']
- * @uses $GLOBALS['server']
- * @uses $GLOBALS['db']
- * @uses $GLOBALS['table']
- * @uses $GLOBALS['available_languages']
- * @uses $GLOBALS['lang']
- * @uses $GLOBALS['text_dir']
- * @uses $GLOBALS['charset']
- * @uses $GLOBALS['pmaThemeImage']
- * @uses $GLOBALS['strNoDatabases']
- * @uses $GLOBALS['strDatabase']
- * @uses $GLOBALS['strGo']
- * @uses $GLOBALS['strSelectADb']
- * @uses $GLOBALS['strNoTablesFound']
- * @uses $GLOBALS['cfg']['LeftFrameLight']
- * @uses $GLOBALS['cfg']['ShowTooltip']
- * @uses $GLOBALS['cfg']['ShowTooltipAliasDB']
- * @uses $GLOBALS['cfg']['DefaultTabDatabase']
- * @uses $GLOBALS['cfgRelation']['commwork']) {
- * @uses PMA_List_Database::getSingleItem()
- * @uses PMA_List_Database::count()
- * @uses PMA_List_Database::getHtmlSelectGrouped()
- * @uses PMA_List_Database::getGroupedDetails()
- * @uses PMA_generate_common_url()
- * @uses PMA_generate_common_hidden_inputs()
- * @uses PMA_getComments();
- * @uses PMA_getTableCount()
- * @uses PMA_getTableList()
- * @uses PMA_getRelationsParam()
- * @uses PMA_outBufferPre()
- * @uses session_write_close()
- * @uses strlen()
- * @uses session_write_close()
- * @uses is_array()
- * @uses implode()
- * @uses htmlspecialchars()
+ * @package PhpMyAdmin
  */
 
 /**
@@ -48,41 +12,48 @@
 require_once './libraries/common.inc.php';
 
 /**
- * finish and cleanup navigation.php script execution
+ * finish and cleanup navigation.php script execution, only to be used in navigation.php
  *
- * @uses $GLOBALS['controllink'] to close it
- * @uses $GLOBALS['userlink'] to close it
- * @uses PMA_DBI_close()
- * @access private only to be used in navigation.php
+ * @access private
  */
 function PMA_exitNavigationFrame()
 {
     echo '</body></html>';
-
-    /**
-     * Close MySQL connections
-     */
-    if (isset($GLOBALS['controllink']) && $GLOBALS['controllink']) {
-        @PMA_DBI_close($GLOBALS['controllink']);
-    }
-    if (isset($GLOBALS['userlink']) && $GLOBALS['userlink']) {
-        @PMA_DBI_close($GLOBALS['userlink']);
-    }
-
     exit;
 }
 
+require_once './libraries/common.lib.php';
+require_once './libraries/RecentTable.class.php';
+
+/**
+ * Check if it is an ajax request to reload the recent tables list.
+ */
+if ($GLOBALS['is_ajax_request'] && $_REQUEST['recent_table']) {
+    PMA_ajaxResponse('', true, array('options' => PMA_RecentTable::getInstance()->getHtmlSelectOption()) );
+}
+
 // keep the offset of the db list in session before closing it
-if (! isset($_SESSION['userconf']['navi_limit_offset'])) {
-    $_SESSION['userconf']['navi_limit_offset'] = 0;
+if (! isset($_SESSION['tmp_user_values']['navi_limit_offset'])) {
+    $_SESSION['tmp_user_values']['navi_limit_offset'] = 0;
+}
+if (! isset($_SESSION['tmp_user_values']['table_limit_offset']) || $_SESSION['tmp_user_values']['table_limit_offset_db'] != $db) {
+    $_SESSION['tmp_user_values']['table_limit_offset'] = 0;
+    $_SESSION['tmp_user_values']['table_limit_offset_db'] = $db;
 }
 if (isset($_REQUEST['pos'])) {
-    $_SESSION['userconf']['navi_limit_offset'] = (int) $_REQUEST['pos'];
+    if (isset($_REQUEST['tpos'])) {
+        $_SESSION['tmp_user_values']['table_limit_offset'] = (int) $_REQUEST['pos'];
+    } else {
+        $_SESSION['tmp_user_values']['navi_limit_offset'] = (int) $_REQUEST['pos'];
+    }
 }
-$pos = $_SESSION['userconf']['navi_limit_offset']; 
-
+$pos = $_SESSION['tmp_user_values']['navi_limit_offset'];
+$tpos = $_SESSION['tmp_user_values']['table_limit_offset'];
 // free the session file, for the other frames to be loaded
-session_write_close();
+// but only if debugging is not enabled
+if (empty($_SESSION['debug'])) {
+    session_write_close();
+}
 
 /**
  * the output compression library
@@ -95,59 +66,78 @@ PMA_outBufferPre();
  * selects the database if there is only one on current server
  */
 if ($GLOBALS['server'] && ! strlen($GLOBALS['db'])) {
-    $GLOBALS['db'] = $GLOBALS['PMA_List_Database']->getSingleItem();
+    $GLOBALS['db'] = $GLOBALS['pma']->databases->getSingleItem();
 }
 
 $db_start = $GLOBALS['db'];
 
 /**
- * the relation library
+ * the relation settings
  */
-require_once './libraries/relation.lib.php';
 $cfgRelation = PMA_getRelationsParam();
 
 /**
- * garvin: For re-usability, moved http-headers to a seperate file.
+ * For re-usability, moved http-headers to a seperate file.
  * It can now be included by libraries/header.inc.php, querywindow.php.
  */
 require_once './libraries/header_http.inc.php';
 
-if (! isset($_SESSION['userconf']['navi_limit_offset'])) {
-    $_SESSION['userconf']['navi_limit_offset'] = 0;
-}
-if (isset($_REQUEST['pos'])) {
-    $_SESSION['userconf']['navi_limit_offset'] = (int) $_REQUEST['pos'];
-}
-$pos = $_SESSION['userconf']['navi_limit_offset']; 
-
 /*
  * Displays the frame
  */
 // xml declaration moves IE into quirks mode, making much trouble with CSS
-/* echo '<?xml version="1.0" encoding="' . $GLOBALS['charset'] . '"?>'; */
+/* echo '<?xml version="1.0" encoding="utf-8"?>'; */
 ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<!DOCTYPE html>
 <html xmlns="http://www.w3.org/1999/xhtml"
-    xml:lang="<?php echo $available_languages[$lang][2]; ?>"
-    lang="<?php echo $available_languages[$lang][2]; ?>"
+    xml:lang="<?php echo $available_languages[$lang][1]; ?>"
+    lang="<?php echo $available_languages[$lang][1]; ?>"
     dir="<?php echo $GLOBALS['text_dir']; ?>">
 
 <head>
     <link rel="icon" href="./favicon.ico" type="image/x-icon" />
     <link rel="shortcut icon" href="./favicon.ico" type="image/x-icon" />
     <title>phpMyAdmin</title>
-    <meta http-equiv="Content-Type"
-        content="text/html; charset=<?php echo $GLOBALS['charset']; ?>" />
+    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
     <base target="frame_content" />
     <link rel="stylesheet" type="text/css"
-        href="phpmyadmin.css.php?<?php echo PMA_generate_common_url('', ''); ?>&amp;js_frame=left&amp;nocache=<?php echo $_SESSION['PMA_Config']->getThemeUniqueValue(); ?>" />
-    <script type="text/javascript" src="js/navigation.js"></script>
-    <script type="text/javascript" src="js/functions.js"></script>
+        href="phpmyadmin.css.php?<?php echo PMA_generate_common_url('', ''); ?>&amp;js_frame=left&amp;nocache=<?php echo $GLOBALS['PMA_Config']->getThemeUniqueValue(); ?>" />
+    <?php
+    echo PMA_includeJS('jquery/jquery-1.6.2.js');
+    echo PMA_includeJS('jquery/jquery-ui-1.8.16.custom.js');
+    echo PMA_includeJS('jquery/jquery.qtip-1.0.0-rc3.js');
+    echo PMA_includeJS('navigation.js');
+    echo PMA_includeJS('functions.js');
+    echo PMA_includeJS('messages.php');
+    // Append the theme id to this url to invalidate the cache on a theme change
+    echo PMA_includeJS('get_image.js.php?theme=' . urlencode($_SESSION['PMA_Theme']->getId()));
+    ?>
     <script type="text/javascript">
     // <![CDATA[
-    var image_minus = '<?php echo $GLOBALS['pmaThemeImage']; ?>b_minus.png';
-    var image_plus = '<?php echo $GLOBALS['pmaThemeImage']; ?>b_plus.png';
+    // INIT PMA_setFrameSize
+    var onloadCnt = 0;
+    var onLoadHandler = window.onload;
+    var resizeHandler = window.onresize;
+    window.document.onresize  = resizeHandler;
+    window.onload = function() {
+        if (onloadCnt == 0) {
+            if (typeof(onLoadHandler) == "function") {
+                onLoadHandler();
+            }
+            if (typeof(PMA_setFrameSize) != 'undefined' && typeof(PMA_setFrameSize) == 'function') {
+                PMA_setFrameSize();
+            }
+            onloadCnt++;
+        }
+    };
+    window.onresize = function() {
+        if (typeof(resizeHandler) == "function") {
+            resizeHandler();
+        }
+        if (typeof(PMA_saveFrameSize) != 'undefined' && typeof(PMA_saveFrameSize) == 'function') {
+            PMA_saveFrameSize();
+        }
+    };
     // ]]>
     </script>
     <?php
@@ -166,17 +156,31 @@ $pos = $_SESSION['userconf']['navi_limit_offset'];
     <![endif]-->
 </head>
 
-<body id="body_leftFrame" onload="PMA_setFrameSize();" onresize="PMA_saveFrameSize();">
+<body id="body_leftFrame">
 <?php
 require './libraries/navigation_header.inc.php';
+
+// display recently used tables
+if ($GLOBALS['cfg']['LeftRecentTable'] > 0) {
+    echo '<div id="recentTableList">' . "\n"
+        .'<form method="post" action="index.php" target="_parent">' . "\n"
+        .PMA_generate_common_hidden_inputs() . "\n"
+        .PMA_RecentTable::getInstance()->getHtmlSelect()
+        .'<noscript>' . "\n"
+        .'<input type="submit" name="Go" value="' . __('Go') . '" />' . "\n"
+        .'</noscript>' . "\n"
+        .'</form>' . "\n"
+        .'</div>' . "\n";
+}
+
 if (! $GLOBALS['server']) {
     // no server selected
     PMA_exitNavigationFrame();
-} elseif (! $GLOBALS['PMA_List_Database']->count()) {
+} elseif (! count($GLOBALS['pma']->databases)) {
     // no database available, so we break here
-    echo '<p>' . $GLOBALS['strNoDatabases'] . '</p>';
+    echo '<p>' . __('No databases') . '</p>';
     PMA_exitNavigationFrame();
-} elseif ($GLOBALS['cfg']['LeftFrameLight'] && $GLOBALS['PMA_List_Database']->count() > 1) {
+} elseif ($GLOBALS['cfg']['LeftFrameLight'] && count($GLOBALS['pma']->databases) > 1) {
     $list = $cfg['DisplayDatabasesList'];
     if ($list === 'auto') {
         if (empty($GLOBALS['db'])) {
@@ -197,25 +201,19 @@ if (! $GLOBALS['server']) {
 
     <div id="databaseList">
     <form method="post" action="index.php" target="_parent" id="left">
-    <label for="lightm_db"><?php echo $GLOBALS['strDatabase']; ?></label>
     <?php
         echo PMA_generate_common_hidden_inputs() . "\n";
-        echo $GLOBALS['PMA_List_Database']->getHtmlSelectGrouped(true, $_SESSION['userconf']['navi_limit_offset'], $GLOBALS['cfg']['MaxDbList']) . "\n";
+        echo $GLOBALS['pma']->databases->getHtmlSelectGrouped(true, $_SESSION['tmp_user_values']['navi_limit_offset'], $GLOBALS['cfg']['MaxDbList']) . "\n";
         echo '<noscript>' . "\n"
-            .'<input type="submit" name="Go" value="' . $GLOBALS['strGo'] . '" />' . "\n"
+            .'<input type="submit" name="Go" value="' . __('Go') . '" />' . "\n"
             .'</noscript>' . "\n"
-            .'</form>' . "\n";
+            .'</form>' . "\n"
+            . '</div>' . "\n";
     } else {
-        if (! empty($db)) {
-            echo '<div id="databaseList">' . "\n";
-        }
-        echo $GLOBALS['PMA_List_Database']->getHtmlListGrouped(true, $_SESSION['userconf']['navi_limit_offset'], $GLOBALS['cfg']['MaxDbList']) . "\n";
+        echo $GLOBALS['pma']->databases->getHtmlListGrouped(true, $_SESSION['tmp_user_values']['navi_limit_offset'], $GLOBALS['cfg']['MaxDbList']) . "\n";
     }
     $_url_params = array('pos' => $pos);
-    PMA_listNavigator($GLOBALS['PMA_List_Database']->count(), $pos, $_url_params, 'navigation.php', 'frame_navigation', $GLOBALS['cfg']['MaxDbList']);
-    if (! empty($db)) {
-        echo '</div>' . "\n";
-    }
+    PMA_listNavigator(count($GLOBALS['pma']->databases), $pos, $_url_params, 'navigation.php', 'frame_navigation', $GLOBALS['cfg']['MaxDbList']);
 }
 ?>
 
@@ -230,17 +228,19 @@ if (! $GLOBALS['server']) {
 //    or $GLOBALS['cfg']['Servers']['only_db'] is defined and is not an array)
 //    In this case, the database should not be collapsible/expandable
 
-$img_plus = '<img class="icon" id="el%dImg" src="' . $pmaThemeImage . 'b_plus.png"'
-    .' width="9" height="9" alt="+" />';
-$img_minus = '<img class="icon" id="el%dImg" src="' . $pmaThemeImage . 'b_minus.png"'
-    .' width="9" height="9" alt="-" />';
+$img_plus = PMA_getImage('b_plus.png', '+', array('id' => 'el%dImg'));
+$img_minus = PMA_getImage('b_minus.png', '-', array('id' => 'el%dImg'));
 
 $href_left = '<a onclick="if (toggle(\'%d\')) return false;"'
     .' href="navigation.php?%s" target="_self">';
 
 $element_counter = 0;
 
+
 if ($GLOBALS['cfg']['LeftFrameLight'] && strlen($GLOBALS['db'])) {
+    $table_list = PMA_getTableList($GLOBALS['db'], null, $tpos, $cfg['MaxTableList']);
+    $table_count = PMA_getTableCount($GLOBALS['db']);
+
     // show selected databasename as link to DefaultTabDatabase-page
     // with table count in ()
     $common_url_query = PMA_generate_common_url($GLOBALS['db']);
@@ -249,9 +249,9 @@ if ($GLOBALS['cfg']['LeftFrameLight'] && strlen($GLOBALS['db'])) {
 
     if ($GLOBALS['cfg']['ShowTooltip']
       && $GLOBALS['cfgRelation']['commwork']) {
-        $_db_tooltip = PMA_getComments($GLOBALS['db']);
-        if (is_array($_db_tooltip)) {
-            $db_tooltip = implode(' ', $_db_tooltip);
+        $_db_tooltip = PMA_getDbComment($GLOBALS['db']);
+        if ($_db_tooltip) {
+            $db_tooltip = $_db_tooltip;
         }
     }
 
@@ -262,89 +262,88 @@ if ($GLOBALS['cfg']['LeftFrameLight'] && strlen($GLOBALS['db'])) {
         $db_tooltip     = $GLOBALS['db'];
     }
 
-    ?>
-    <p><a class="item"
-        href="<?php echo $GLOBALS['cfg']['DefaultTabDatabase'] . '?' . $common_url_query; ?>"
-        title="<?php echo htmlspecialchars($db_tooltip); ?>" >
-    <?php
-    if ($GLOBALS['text_dir'] === 'rtl') {
-        echo ' <bdo dir="ltr">(' . PMA_getTableCount($GLOBALS['db']) . ')</bdo> ';
+    if ($table_count >= $GLOBALS['cfg']['LeftDisplayTableFilterMinimum']) {
+        ?>
+        <span id="NavFilter">
+        <span id="clear_fast_filter" title="<?php echo __('Clear'); ?>">X</span>
+            <input type="text" class="gray" name="fast_filter" id="fast_filter" title="<?php echo __('Filter tables by name'); ?>" value="<?php echo __('Filter tables by name'); ?>" />
+        </span>
+        <?php
     }
-    echo '<span class="navi_dbName">' . htmlspecialchars($disp_name) . '</span>';
-    if ($GLOBALS['text_dir'] === 'ltr') {
-        echo ' <bdo dir="ltr">(' . PMA_getTableCount($GLOBALS['db']) . ')</bdo> ';
-    }
-    echo '</a></p>';
 
     /**
      * This helps reducing the navi panel size; in the right panel,
      * user can find a navigator to page thru all tables.
      *
-     * @todo instead of the 0 parameter, keep track of the
-     *       offset in the list of tables ($_SESSION['userconf']['table_limit_offset'])
-     *       and use PMA_listNavigator(); do not just check pos in REQUEST
-     *       but add another hidden param to see if it's the pos of databases
-     *       or the pos of tables. 
      */
-    $table_list = PMA_getTableList($GLOBALS['db'], null, 0, $cfg['MaxTableList']);
     if (! empty($table_list)) {
+        // upper table list paginator
+        if (count($table_list) <= $GLOBALS['cfg']['MaxTableList'] && $table_count > $GLOBALS['cfg']['MaxTableList']) {
+            $_url_params = array(
+              'tpos' => 'true',
+              'pos' => $tpos,
+              'db' => $GLOBALS['db']
+            );
+            PMA_listNavigator($table_count, $tpos, $_url_params, 'navigation.php', 'frame_navigation', $GLOBALS['cfg']['MaxTableList']);
+        }
         PMA_displayTableList($table_list, true, '', $GLOBALS['db']);
-        // hint user that the table list is larger, until the todo is done
-        if (count($table_list) <= $GLOBALS['cfg']['MaxTableList'] && PMA_getTableCount($GLOBALS['db']) > $GLOBALS['cfg']['MaxTableList']) {
-            echo '&nbsp; ( 1 .. ', $GLOBALS['cfg']['MaxTableList'], ' / ', PMA_getTableCount($GLOBALS['db']), ' )'; 
-        } 
+        // lower table list paginator
+        if (count($table_list) <= $GLOBALS['cfg']['MaxTableList'] && $table_count > $GLOBALS['cfg']['MaxTableList']) {
+            PMA_listNavigator($table_count, $tpos, $_url_params, 'navigation.php', 'frame_navigation', $GLOBALS['cfg']['MaxTableList']);
+        }
     } else {
-        echo $GLOBALS['strNoTablesFound'];
+        echo __('No tables found in database.');
     }
     unset($table_list);
+    if (!PMA_is_system_schema($db)) {
+        $class = '';
+        $GLOBALS['cfg']['AjaxEnable'] ? $class="ajax" : '';
+        echo '<ul id="newtable"><li><a target="frame_content" href="tbl_create.php' . PMA_generate_common_url(array('db' => $GLOBALS['db'])) . '"  class="'.$class .'" >'
+            . PMA_getImage('b_snewtbl.png', _pgettext('short form', 'Create table'), array('id' => "icon_newtable"))
+            . _pgettext('short form', 'Create table') . '</a></li></ul>';
+    }
 } elseif ($GLOBALS['cfg']['LeftFrameLight']) {
-    echo '<p>' . $GLOBALS['strSelectADb'] . '</p>' . "\n";
+    /* No need to tell user to select database if we're showing complete list */
+    if (!$list) {
+        echo '<p>' . __('Please select a database') . '</p>';
+    }
 } else {
     echo '<div id="databaseList">' . "\n";
     $_url_params = array('pos' => $pos);
-    PMA_listNavigator($GLOBALS['PMA_List_Database']->count(), $pos, $_url_params, 'navigation.php', 'frame_navigation', $GLOBALS['cfg']['MaxDbList']);
+    PMA_listNavigator(count($GLOBALS['pma']->databases), $pos, $_url_params, 'navigation.php', 'frame_navigation', $GLOBALS['cfg']['MaxDbList']);
     echo '</div>' . "\n";
 
     $common_url_query = PMA_generate_common_url();
-    PMA_displayDbList($GLOBALS['PMA_List_Database']->getGroupedDetails($_SESSION['userconf']['navi_limit_offset'],$GLOBALS['cfg']['MaxDbList']), $_SESSION['userconf']['navi_limit_offset'],$GLOBALS['cfg']['MaxDbList']);
+    PMA_displayDbList($GLOBALS['pma']->databases->getGroupedDetails($_SESSION['tmp_user_values']['navi_limit_offset'], $GLOBALS['cfg']['MaxDbList']), $_SESSION['tmp_user_values']['navi_limit_offset'], $GLOBALS['cfg']['MaxDbList']);
 }
 
 /**
  * displays collapsable db list
  *
- * @uses    $_REQUEST['dbgroup']
- * @uses    $GLOBALS['cfg']['DefaultTabDatabase']
- * @uses    $GLOBALS['strSelectADb']
- * @uses    strpos()
- * @uses    urlencode()
- * @uses    printf()
- * @uses    htmlspecialchars()
- * @uses    PMA_generate_common_url()
- * @uses    PMA_getTableList()
- * @uses    PMA_displayTableList()
- * @global  $element_counter
- * @global  $img_minus
- * @global  $img_plus
- * @global  $href_left
- * @global  $db_start
- * @global  $common_url_query
- * @param   array   $ext_dblist extended db list
- * @param   integer $offset
- * @param   integer $count
+ * @global  integer $element_counter
+ * @global  string $img_minus
+ * @global  string $img_plus
+ * @global  string $href_left
+ * @global  string $db_start
+ * @global  string $common_url_query
+ * @param array   $ext_dblist extended db list
+ * @param integer $offset
+ * @param integer $count
  */
-function PMA_displayDbList($ext_dblist, $offset, $count) {
+function PMA_displayDbList($ext_dblist, $offset, $count)
+{
     global $element_counter, $img_minus, $img_plus, $href_left,
         $db_start, $common_url_query;
 
     // get table list, for all databases
     // doing this in one step takes advantage of a single query with information_schema!
-    $tables_full = PMA_DBI_get_tables_full($GLOBALS['PMA_List_Database']->getLimitedItems($offset, $count));
+    $tables_full = PMA_DBI_get_tables_full($GLOBALS['pma']->databases->getLimitedItems($offset, $count));
 
     $url_dbgroup = '';
     echo '<ul id="leftdatabaselist">';
     $close_db_group = false;
     foreach ($ext_dblist as $group => $db_group) {
-        if ($GLOBALS['PMA_List_Database']->count() > 1) {
+        if (count($GLOBALS['pma']->databases) > 1) {
             if ($close_db_group) {
                 $url_dbgroup = '';
                 echo '</ul>';
@@ -383,7 +382,7 @@ function PMA_displayDbList($ext_dblist, $offset, $count) {
             // Displays the database name
             echo '<li>' . "\n";
 
-            if ($GLOBALS['PMA_List_Database']->count() > 1) {
+            if (count($GLOBALS['pma']->databases) > 1) {
                 // only with more than one db we need collapse ...
                 if ($db_start != $db['name'] || $db['num_tables'] < 1) {
                     // display + only if this db is not preselected
@@ -411,18 +410,23 @@ function PMA_displayDbList($ext_dblist, $offset, $count) {
                             . '?' . $common_url_query; ?>', 'main');
                         return false;">
                     <?php
-                    if ($GLOBALS['text_dir'] === 'rtl') {
-                        echo ' <bdo dir="ltr">(' . $db['num_tables'] . ')</bdo> ';
+                    // Might be unset if CountTables directive is false
+                    if (isset($db['num_tables'])) {
+                        if ($GLOBALS['text_dir'] === 'rtl') {
+                            echo ' <bdo dir="ltr">(' . $db['num_tables'] . ')</bdo> ';
+                        }
                     }
                     echo htmlspecialchars($db['disp_name']);
-                    if ($GLOBALS['text_dir'] === 'ltr') {
-                        echo ' <bdo dir="ltr">(' . $db['num_tables'] . ')</bdo> ';
+                    if (isset($db['num_tables'])) {
+                        if ($GLOBALS['text_dir'] === 'ltr') {
+                            echo ' <bdo dir="ltr">(' . $db['num_tables'] . ')</bdo> ';
+                        }
                     }
                     ?>
                 </a>
                 <?php
             } else {
-                // with only 1 db available we dont need to refresh left frame
+                // with only 1 db available we dont need to refresh navi frame
                 // on db selection, only phpmain
                 ?>
                 <a href="<?php echo $GLOBALS['cfg']['DefaultTabDatabase']
@@ -430,18 +434,22 @@ function PMA_displayDbList($ext_dblist, $offset, $count) {
                     id="<?php echo htmlspecialchars($db['name']); ?>"
                     title="<?php echo htmlspecialchars($db['comment']); ?>">
                     <?php
-                    if ($GLOBALS['text_dir'] === 'rtl') {
-                        echo ' <bdo dir="ltr">(' . $db['num_tables'] . ')</bdo> ';
+                    if (isset($db['num_tables'])) {
+                        if ($GLOBALS['text_dir'] === 'rtl') {
+                            echo ' <bdo dir="ltr">(' . $db['num_tables'] . ')</bdo> ';
+                        }
                     }
                     echo htmlspecialchars($db['disp_name']);
-                    if ($GLOBALS['text_dir'] === 'ltr') {
-                        echo ' <bdo dir="ltr">(' . $db['num_tables'] . ')</bdo> ';
+                    if (isset($db['num_tables'])) {
+                        if ($GLOBALS['text_dir'] === 'ltr') {
+                            echo ' <bdo dir="ltr">(' . $db['num_tables'] . ')</bdo> ';
+                        }
                     }
                     ?>
                 </a>
                 <?php
             }
-            if ($db['num_tables']) {
+            if (($GLOBALS['cfg']['Server']['CountTables'] === false) || $db['num_tables']) {
                 if (isset($tables_full[$db['name']])) {
                     $tables = PMA_getTableList($db['name'], $tables_full[$db['name']]);
                 } elseif (isset($tables_full[strtolower($db['name'])])) {
@@ -455,13 +463,13 @@ function PMA_displayDbList($ext_dblist, $offset, $count) {
                 } else {
                     $tables = PMA_getTableList($db['name']);
                 }
-                $child_visible =
-                    (bool) ($GLOBALS['PMA_List_Database']->count() === 1 || $db_start == $db['name']);
+                $child_visible
+                    = (bool) (count($GLOBALS['pma']->databases) === 1 || $db_start == $db['name']);
                 PMA_displayTableList($tables, $child_visible, '', $db['name']);
             } elseif ($GLOBALS['cfg']['LeftFrameLight']) {
                 // no tables and LeftFrameLight:
                 // display message no tables in selected db
-                echo '<p>' . $GLOBALS['strSelectADb'] . '</p>' . "\n";
+                echo '<p>' . __('Please select a database') . '</p>' . "\n";
             }
             echo '</li>' . "\n";
         } // end foreach db
@@ -482,32 +490,14 @@ function PMA_displayDbList($ext_dblist, $offset, $count) {
  * calls itself recursively if table in given list
  * is a list itself
  *
- * @uses    is_array()
- * @uses    count()
- * @uses    urlencode()
- * @uses    strpos()
- * @uses    printf()
- * @uses    htmlspecialchars()
- * @uses    strlen()
- * @uses    is_array()
- * @uses    PMA_displayTableList()
- * @uses    $_REQUEST['tbl_group']
- * @uses    $GLOBALS['common_url_query']
- * @uses    $GLOBALS['table']
- * @uses    $GLOBALS['pmaThemeImage']
- * @uses    $GLOBALS['cfg']['LeftFrameTableSeparator']
- * @uses    $GLOBALS['cfg']['DefaultTabDatabase']
- * @uses    $GLOBALS['cfg']['DefaultTabTable']
- * @uses    $GLOBALS['strRows']
- * @uses    $GLOBALS['strBrowse']
  * @global  integer the element counter
  * @global  string  html code for '-' image
  * @global  string  html code for '+' image
  * @global  string  html code for self link
- * @param   array   $tables         array of tables/tablegroups
- * @param   boolean $visible        wether the list is visible or not
- * @param   string  $tab_group_full full tab group name
- * @param   string  $table_db       db of this table
+ * @param array   $tables         array of tables/tablegroups
+ * @param boolean $visible        whether the list is visible or not
+ * @param string  $tab_group_full full tab group name
+ * @param string  $table_db       db of this table
  */
 function PMA_displayTableList($tables, $visible = false,
     $tab_group_full = '', $table_db = '')
@@ -525,7 +515,8 @@ function PMA_displayTableList($tables, $visible = false,
         echo '<ul id="subel' . $element_counter . '" style="display: none">';
     }
     foreach ($tables as $group => $table) {
-        if (isset($table['is' . $sep . 'group'])) {
+        // only allow grouping if the group has more than 1 table
+        if (isset($table['is' . $sep . 'group']) && $table['tab' . $sep . 'count'] > 1) {
             $common_url_query = $GLOBALS['common_url_query']
                 . '&amp;tbl_group=' . urlencode($tab_group_full . $group);
 
@@ -581,28 +572,43 @@ function PMA_displayTableList($tables, $visible = false,
             }
             echo '</li>' . "\n";
         } elseif (is_array($table)) {
+            // the table was not grouped because it is the only one with its prefix
+            while (isset($table['is' . $sep . 'group'])) {
+                // get the array with the actual table information
+                foreach ($table as $value) {
+                    if (is_array($value)) {
+                        $table = $value;
+                    }
+                }
+            }
+            $link_title = PMA_getTitleForTarget($GLOBALS['cfg']['LeftDefaultTabTable']);
+            // quick access icon next to each table name
+            echo '<li>' . "\n";
+            echo '<a class="tableicon" title="'
+                . htmlspecialchars($link_title)
+                . ': ' . htmlspecialchars($table['Comment'])
+                .' (' . PMA_formatNumber($table['Rows'], 0) . ' ' . __('Rows') . ')"'
+                .' id="quick_' . htmlspecialchars($table_db . '.' . $table['Name']) . '"'
+                .' href="' . $GLOBALS['cfg']['LeftDefaultTabTable'] . '?'
+                . $GLOBALS['common_url_query']
+                .'&amp;table=' . urlencode($table['Name'])
+                .'&amp;goto=' . $GLOBALS['cfg']['LeftDefaultTabTable']
+                . '" >';
+            $attr = array('id' => 'icon_' . htmlspecialchars($table_db . '.' . $table['Name']));
+            if (PMA_Table::isView($table_db, $table['Name'])) {
+                echo PMA_getImage('s_views.png', htmlspecialchars($link_title), $attr);
+            } else {
+                echo PMA_getImage('b_browse.png', htmlspecialchars($link_title), $attr);
+            }
+            echo '</a>';
+
+            // link for the table name itself
             $href = $GLOBALS['cfg']['DefaultTabTable'] . '?'
                 .$GLOBALS['common_url_query'] . '&amp;table='
-                .urlencode($table['Name']);
-            echo '<li>' . "\n";
-            echo '<a title="' . $GLOBALS['strBrowse'] . ': '
-                . htmlspecialchars($table['Comment'])
-                .' (' . PMA_formatNumber($table['Rows'], 0) . ' ' . $GLOBALS['strRows'] . ')"'
-                .' id="browse_' . htmlspecialchars($table_db . '.' . $table['Name']) . '"'
-                .' href="sql.php?' . $GLOBALS['common_url_query']
-                .'&amp;table=' . urlencode($table['Name'])
-                .'&amp;goto=' . $GLOBALS['cfg']['DefaultTabTable']
-                . '" >'
-                .'<img class="icon"';
-            if ('VIEW' === strtoupper($table['Comment'])) {
-                echo ' src="' . $GLOBALS['pmaThemeImage'] . 's_views.png"';
-            } else {
-                echo ' src="' . $GLOBALS['pmaThemeImage'] . 'b_sbrowse.png"';
-            }
-            echo ' id="icon_' . htmlspecialchars($table_db . '.' . $table['Name']) . '"'
-                .' width="10" height="10" alt="' . $GLOBALS['strBrowse'] . '" /></a>' . "\n"
-                .'<a href="' . $href . '" title="' . htmlspecialchars($table['Comment']
-                .' (' . PMA_formatNumber($table['Rows'], 0) . ' ' . $GLOBALS['strRows']) . ')"'
+                .urlencode($table['Name']) . '&amp;pos=0';
+            echo '<a href="' . $href
+            . '" title="' . htmlspecialchars(PMA_getTitleForTarget($GLOBALS['cfg']['DefaultTabTable']) . ': ' . $table['Comment']
+                .' (' . PMA_formatNumber($table['Rows'], 0) . ' ' . __('Rows')) . ')"'
                 .' id="' . htmlspecialchars($table_db . '.' . $table['Name']) . '">'
                 // preserve spaces in table name
                 . str_replace(' ', '&nbsp;', htmlspecialchars($table['disp_name'])) . '</a>';
